Modules
Functions
- decode
- Decode a TOON string into a JSON value.
- decode_
from_ lines - Decode TOON lines into a JSON value.
- decode_
stream - Decode TOON lines into a stream of events asynchronously.
- decode_
stream_ sync - Decode TOON lines into a stream of events.
- try_
decode - Try to decode a TOON string into a JSON value, returning a Result.
- try_
decode_ from_ lines - Try to decode TOON lines into a JSON value, returning a Result.
- try_
decode_ stream - Try to decode TOON lines into a stream of events asynchronously, returning a Result.
- try_
decode_ stream_ sync - Try to decode TOON lines into a stream of events, returning a Result.