pub fn parse_primitive_token(token: &str) -> Result<JsonPrimitive>Expand description
Parse a primitive token into a JSON primitive.
Errors
Returns an error if a quoted string token is unterminated or malformed.
pub fn parse_primitive_token(token: &str) -> Result<JsonPrimitive>Parse a primitive token into a JSON primitive.
Returns an error if a quoted string token is unterminated or malformed.