parse_quoted_key

Function parse_quoted_key 

pub fn parse_quoted_key(content: &str, start: usize) -> Result<(String, usize)>
Parse a quoted key and validate the following colon.

Errors

Returns an error for unterminated quotes or missing colon.