Module validation

Module validation 

Functions

assert_expected_count
Assert the expected count in strict mode.
validate_no_blank_lines_in_range
Validate that no blank lines appear within the specified range.
validate_no_extra_list_items
Validate that there are no extra list items beyond the expected count.
validate_no_extra_tabular_rows
Validate that there are no extra tabular rows beyond the expected count.