Structs
Functions
- is_
array_ header_ content - is_
key_ value_ content - map_
row_ values_ to_ primitives - Map delimited string values into JSON primitives.
- parse_
array_ header_ line - Parse a TOON array header line, returning header metadata and inline values.
- parse_
bracket_ segment - Parse the bracket length segment, extracting length and delimiter.
- parse_
delimited_ values - parse_
key_ token - Parse a key token (quoted or unquoted) and return key, end index, and quoted flag.
- parse_
primitive_ token - Parse a primitive token into a JSON primitive.
- parse_
quoted_ key - Parse a quoted key and validate the following colon.
- parse_
string_ literal - Parse a quoted string literal, unescaping escape sequences.
- parse_
unquoted_ key - Parse an unquoted key up to the colon delimiter.